##########################################################################################
#
# Magisk模块安装脚本
#
##########################################################################################
##########################################################################################
#
# 说明:
#
# 1. 将文件放入系统文件夹（删除占位符文件）
# 2. 将模块的信息填入module.prop
# 3. 在此文件中配置和实现调用
# 4. 如果需要启动脚本，请将它们添加到common/post-fs-data.sh或common/service.sh
# 5. 将附加或修改的系统属性添加到common/system.prop
#
##########################################################################################

##########################################################################################
# 配置 Flags
##########################################################################################

# system 启用=true,关闭=false
SKIPMOUNT=false

# system.prop 启用=true,关闭=false
PROPFILE=false

# post-fs-data 启用=true,关闭=false
POSTFSDATA=false

# service.sh 启用=true,关闭=false
LATESTARTSERVICE=true

##########################################################################################
# 替换列表
##########################################################################################

# 列出要在系统中直接替换的所有目录
# 查看官方文档以获取有关您需要的更多信息

# 按以下格式构建列表
# 这是一个例子
REPLACE_EXAMPLE="
/system/app/Youtube
/system/priv-app/SystemUI
/system/priv-app/Settings
/system/framework
"

# 在这里构建自定义列表
REPLACE="
"

##########################################################################################
#
# 函数调用
#
# 安装框架将调用以下函数。
# 您无法修改update-binary，这是您可以自定义的唯一方法
# 安装时通过实现这些功能。
#
# 在运行回调时，安装框架将确保Magisk
# 内部busybox的路径是*PREPENDED*到PATH,因此,所有常用命令应存在。
# 此外,它还将确保正确安装/data, /system和/vendor.
#
##########################################################################################
##########################################################################################
#
# 安装框架将导出一些变量和函数。
# 您应该使用这些变量和函数进行安装。
# 
# !不要使用任何Magisk内部路径，因为它们不是公共API。
# !请勿在util_functions.sh中使用其他函数，因为它们不是公共API。
# !不保证非公共API可以保持版本之间的兼容性。
#
# 可用变量:
#
# MAGISK_VER (string): the version string of current installed Magisk
# MAGISK_VER_CODE (int): the version code of current installed Magisk
# BOOTMODE (bool): true if the module is currently installing in Magisk Manager
# MODPATH (path): the path where your module files should be installed
# TMPDIR (path): a place where you can temporarily store files
# ZIPFILE (path): your module's installation zip
# ARCH (string): the architecture of the device. Value is either arm, arm64, x86, or x64
# IS64BIT (bool): true if $ARCH is either arm64 or x64
# API (int): the API level (Android version) of the device
#
# 可用功能:
#
# ui_print <msg>
#     print <msg> to console
#     Avoid using 'echo' as it will not display in custom recovery's console
#
# abort <msg>
#     print error message <msg> to console and terminate installation
#     Avoid using 'exit' as it will skip the termination cleanup steps
#
# set_perm <target> <owner> <group> <permission> [context]
#     if [context] is empty, it will default to "u:object_r:system_file:s0"
#     this function is a shorthand for the following commands
#       chown owner.group target
#       chmod permission target
#       chcon context target
#
# set_perm_recursive <directory> <owner> <group> <dirpermission> <filepermission> [context]
#     if [context] is empty, it will default to "u:object_r:system_file:s0"
#     for all files in <directory>, it will call:
#       set_perm file owner group filepermission context
#     for all directories in <directory> (including itself), it will call:
#       set_perm dir owner group dirpermission context
#
##########################################################################################
##########################################################################################
# 如果需要启动脚本，请不要使用通用启动脚本 (post-fs-data.d/service.d)
# 只使用模块的脚本，因为它尊重模块状态 (remove/disable) and is
# 保证在未来的Magisk版本中保持相同的行为.
# 通过设置上面config部分中的标志启用引导脚本.
##########################################################################################

# 设置安装模块时要显示的内容
print_modname() {
  ui_print "===================================="
  ui_print " "
  ui_print " "
  ui_print " "
  ui_print "     	       【王者优化】"
  ui_print " "
  ui_print " "
  ui_print " "
  ui_print "===================================="
  ui_print " 🏀⚾🏐🥎⚽【乄代号9527】⚽🥎🏐⚾🏀"
  ui_print "===================================="


wz=/data/data/com.tencent.tmgp.sgame/shared_prefs
vt=${wz}/com.tencent.tmgp.sgame.v2.playerprefs.xml
killall -9 'com.tencent.tmgp.sgame'
chattr -i "$vt"
cp $vt /$vt.VT.bak

if [ ! -f "$vt" ]; then
  ui_print "– 未找到配置文件！"
  ui_print "– 更改失败！"
exit;
fi

  ui_print "– 更改配置";
chmod 755 "$vt"
sed -i 's/.*<int name=".*GLES3" value=".*" \/>/    <int name="EnableGLES3" value="1" \/>/g' "$vt"
sed -i 's/.*<int name=".*MTR" value=".*" \/>/    <int name="EnableMTR" value="1" \/>/g' "$vt"
sed -i 's/.*<int name=".*Vulkan" value=".*" \/>/    <int name="EnableVulkan" value="3" \/>/g' "$vt"
chmod 440 "$vt"
chattr +i "$vt"
  ui_print "– 更改成功";
}

# 在安装脚本中将模块文件复制/解压缩到 $MODPATH.

on_install() {
  # 以下是默认设置: 将 $ZIPFILE/system解压缩到 $MODPATH
  # Extend/change the logic to whatever you want
  unzip -o "$ZIPFILE" 'system/*' -d $MODPATH >&2
}

# 只有一些特殊文件需要特定权限
# 安装完成后，此功能将被调用
# 对于大多数情况，默认权限应该已经足够

set_permissions() {
  # 以下是默认规则,请勿删除
  set_perm_recursive $MODPATH 0 0 0755 0644

  # 以下是一些例子:
  # set_perm_recursive  $MODPATH/system/lib       0     0       0755      0644
  # set_perm  $MODPATH/system/bin/app_process32   0     2000    0755      u:object_r:zygote_exec:s0
  # set_perm  $MODPATH/system/bin/dex2oat         0     2000    0755      u:object_r:dex2oat_exec:s0
  # set_perm  $MODPATH/system/lib/libart.so       0     0       0644
}

# 您可以添加更多功能来协助您的自定义脚本代码